Project Contributors
====================

The following people have made contributions to the project (in alphabetical
order by last name) and are considered "The icepyx Developers":

* `Nicole Abib <https://github.com/nabib/>`_ - University of Oregon
* `Anthony Arendt <https://github.com/aaarendt/>`_ - University of Washington
* `Kelsey Bisson <https://github.com/kelseybisson>`_ - Oregon State University
* `Shashank Bhushan <https://github.com/ShashankBice>`_ - University of Washington
* `Alessandro Di Bella <https://github.com/alexdibella>`_ - Technical University of Denmark
* `Raphael Hagen <https://github.com/norlandrhagen>`_ - University of Washington
* `Scott Henderson <https://github.com/scottyhq>`_ - University of Washington
* `Thomas Johnson <https://github.com/loudTom>`_ - University College London
* `Zheng Liu <https://github.com/liuzheng-arctic>`_ - University of Washington
* `Ted Maksym <https://github.com/tedmaksym>`_ - Woods Hole Oceanographic Institution
* `Joachim Meyer <https://github.com/jomey>`_ - University of Utah
* `Fernando Perez <https://github.com/fperez>`_ - University of California, Berkeley
* `Romina Piunno <https://github.com/RomiP>`_ - University of Toronto
* `Facundo Sapienza <https://github.com/facusapienza21>`_ - University of California, Berkeley
* `Jessica Scheick <https://github.com/jessicas11>`_ - Unaffiliated (ORCID: `0000-0002-3421-4459 <https://www.orcid.org/0000-0002-3421-4459>`_)
* `David Shean <https://github.com/dshean>`_ - University of Washington
* `Ben Smith <https://github.com/smithb>`_ - University of Washington
* `Amy Steiker <https://github.com/asteiker>`_ - NSIDC, University of Colorado
* `Tyler Sutterley <https://github.com/tsutterley>`_ - University of Washington
* `Anna Valentine <https://github.com/annavalentine>`_ - Colorado School of Mines
* `Bruce Wallin <https://github.com/wallinb>`_ - NSIDC, University of Colorado
* `Molly Wieringa <https://github.com/mollymwieringa>`_ - University of Washington
* `Bidhyananda Yadav <https://github.com/bidhya>`_ - Ohio State University
